@@ -1,3 +1,6 @@
+# SPDX-FileCopyrightText: 2021 Melissa LeBlanc-Williams for Adafruit Industries
+#
+# SPDX-License-Identifier: MIT
 import time
 import board
 import busio
@@ -9,5 +12,5 @@ spi.configure(baudrate=16000000)
 spi.unlock()
 
 while True:
-    spi.write(bytes([x for x in range(64)]))
+    spi.write(bytes(range(64)))
     time.sleep(0.1)
