@@ -11,7 +11,7 @@ See `CircuitPython:board` in CircuitPython for more details.
 """
 
 
-__version__ = "8.16.1"
+__version__ = "8.22.3"
 __repo__ = "https://github.com/adafruit/Adafruit_Blinka.git"
 __blinka__ = True
 
@@ -61,6 +61,9 @@ elif board_id == ap_board.BEAGLEBONE:
 elif board_id == ap_board.BEAGLEBONE_BLACK:
     from adafruit_blinka.board.beagleboard.beaglebone_black import *
 
+elif board_id == ap_board.BEAGLEBONE_BLUE:
+    from adafruit_blinka.board.beagleboard.beaglebone_blue import *
+
 elif board_id == ap_board.BEAGLEBONE_GREEN:
     from adafruit_blinka.board.beagleboard.beaglebone_black import *
 
@@ -139,6 +142,9 @@ elif board_id == ap_board.BANANA_PI_M2_PLUS:
 elif board_id == ap_board.BANANA_PI_M5:
     from adafruit_blinka.board.bananapi.bpim5 import *
 
+elif board_id == ap_board.LEMAKER_BANANA_PRO:
+    from adafruit_blinka.board.lemaker.bananapro import *
+
 elif board_id == ap_board.GIANT_BOARD:
     from adafruit_blinka.board.giantboard import *
 
@@ -163,6 +169,9 @@ elif board_id == ap_board.JETSON_NX:
 elif board_id == ap_board.JETSON_AGX_ORIN:
     from adafruit_blinka.board.nvidia.jetson_orin import *
 
+elif board_id in (ap_board.JETSON_ORIN_NX, ap_board.JETSON_ORIN_NANO):
+    from adafruit_blinka.board.nvidia.jetson_orin_nx import *
+
 elif board_id == ap_board.CLARA_AGX_XAVIER:
     from adafruit_blinka.board.nvidia.clara_agx_xavier import *
 
@@ -242,7 +251,7 @@ elif board_id == ap_board.ROCK_PI_4:
     from adafruit_blinka.board.radxa.rockpi4 import *
 
 elif board_id == ap_board.ROCK_PI_4_C_PLUS:
-    from adafruit_blinka.board.radxa.rockpi4cplus import *
+    from adafruit_blinka.board.radxa.rockpi4 import *
 
 elif board_id == ap_board.ROCK_PI_5:
     from adafruit_blinka.board.radxa.rock5 import *
@@ -295,6 +304,15 @@ elif board_id == ap_board.PICO_U2IF:
 elif board_id == ap_board.FEATHER_U2IF:
     from adafruit_blinka.board.feather_u2if import *
 
+elif board_id == ap_board.FEATHER_CAN_U2IF:
+    from adafruit_blinka.board.feather_can_u2if import *
+
+elif board_id == ap_board.FEATHER_EPD_U2IF:
+    from adafruit_blinka.board.feather_epd_u2if import *
+
+elif board_id == ap_board.FEATHER_RFM_U2IF:
+    from adafruit_blinka.board.feather_rfm_u2if import *
+
 elif board_id == ap_board.QTPY_U2IF:
     from adafruit_blinka.board.qtpy_u2if import *
 
@@ -307,6 +325,9 @@ elif board_id == ap_board.MACROPAD_U2IF:
 elif board_id == ap_board.QT2040_TRINKEY_U2IF:
     from adafruit_blinka.board.qt2040_trinkey_u2if import *
 
+elif board_id == ap_board.KB2040_U2IF:
+    from adafruit_blinka.board.kb2040_u2if import *
+
 elif board_id == ap_board.LICHEE_RV:
     from adafruit_blinka.board.lichee_rv import *
 
@@ -334,15 +355,20 @@ elif board_id is None:
 
     package = str(pkg_resources.get_distribution("adafruit_platformdetect")).split()
     raise NotImplementedError(
-        "{1} version {2} was unable to identify the board and/or microcontroller running "
-        "the {0} platform. Please be sure you have the latest packages running: 'pip3 install "
-        "--upgrade adafruit-blinka adafruit-platformdetect'".format(
-            platform.system(), package[0], package[1]
-        )
+        f"""
+        {package[0]} version {package[1]} was unable to identify the board and/or
+        microcontroller running the {platform.system()} platform. Please be sure you
+        have the latest packages by running:
+        'pip3 install --upgrade adafruit-blinka adafruit-platformdetect'
+
+        If you are running the latest package, your board may not yet be supported. Please
+        open a New Issue on GitHub at https://github.com/adafruit/Adafruit_Blinka/issues and
+        select New Board Request.
+        """
     )
 
 else:
-    raise NotImplementedError("Board not supported {}".format(board_id))
+    raise NotImplementedError(f"Board not supported {board_id}.")
 
 if "SCL" in locals() and "SDA" in locals():
 
